summaryrefslogtreecommitdiff
path: root/nuttx/arch/avr/src/atmega
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-06-15 23:54:25 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-06-15 23:54:25 +0000
commitc70a8e40fe9eed5b9c5460d1b4a4160f20d7e72c (patch)
tree4072756cd5eaa266c4ee4f6527a7a3369e5e3b69 /nuttx/arch/avr/src/atmega
parentebcd165244ce88f7c34d483f0aee8acbfaad112f (diff)
downloadpx4-nuttx-c70a8e40fe9eed5b9c5460d1b4a4160f20d7e72c.tar.gz
px4-nuttx-c70a8e40fe9eed5b9c5460d1b4a4160f20d7e72c.tar.bz2
px4-nuttx-c70a8e40fe9eed5b9c5460d1b4a4160f20d7e72c.zip
Make room for the noinit section before the heap
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@3710 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/arch/avr/src/atmega')
-rwxr-xr-xnuttx/arch/avr/src/atmega/atmega_head.S12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/arch/avr/src/atmega/atmega_head.S b/nuttx/arch/avr/src/atmega/atmega_head.S
index cad7e54c8..9b6581ce7 100755
--- a/nuttx/arch/avr/src/atmega/atmega_head.S
+++ b/nuttx/arch/avr/src/atmega/atmega_head.S
@@ -47,9 +47,9 @@
* Pre-processor definitions
****************************************************************************/
-/* Stack is allocated just after .bss and before the heap */
+/* Stack is allocated just after uninitialized data and just before the heap */
-#define STACKBASE (_ebss+CONFIG_IDLETHREAD_STACKSIZE-4)
+#define STACKBASE (_enoinit+CONFIG_IDLETHREAD_STACKSIZE-1)
/* The RAMPZ register is only available for CPUs with more than 64Kb of FLASH.
* At present, only the ATMega128 is supported so RAMPZ should always be
@@ -72,6 +72,7 @@
.global _sdata /* Start of .data section in RAM */
.global _edata /* End of .data section in RAM */
.global _eronly /* Start of .data section in FLASH */
+ .global _enoinit /* End of uninitilized data. Defined by ld.script */
.global up_lowinit /* Perform low level initialization */
.global os_start /* NuttX entry point */
@@ -257,15 +258,14 @@ __do_clear_bss:
* Heap Base
****************************************************************************/
/* This global variable is unsigned long g_heapbase and is
* exported from here only because of its coupling to other
* uses of _ebss in this file
*/
.data
.globl g_heapbase
.type g_heapbase, object
g_heapbase:
- .word _ebss+CONFIG_IDLETHREAD_STACKSIZE
+ .word _enoinit+CONFIG_IDLETHREAD_STACKSIZE
.size g_heapbase, .-g_heapbase
.end
@@ -257,15 +258,14 @@ __do_clear_bss:
* Heap Base
****************************************************************************/
- /* This global variable is unsigned long g_heapbase and is
- * exported from here only because of its coupling to other
- * uses of _ebss in this file
+ /* This global variable is unsigned long g_heapbase and is exported from
+ * here only because of its coupling to other uses of _enoinit in this file
*/
.data